const LOG = require('./utils/logger')
const TOPICS = require('./utils/topics')
const PUB_SUB = require('./utils/pub-sub')
const reactNative = require('./frameworks/react-native')
const sourcemapUploader = require('./services/sourcemap-uploader')
const FILE_HELPER = require('./utils/file-helper')
const CONSTANTS = require('./constants')
const { PATHS } = CONSTANTS

module.exports = class App {
  constructor() {
  }

  setup() {
    PUB_SUB.subscribe(TOPICS.actions.add.reactNative, reactNative.install.handleReact)
    PUB_SUB.subscribe(TOPICS.actions.add.rnIos, reactNative.install.handleIos)
    PUB_SUB.subscribe(TOPICS.actions.add.rnAndroid, reactNative.install.handleAndroid)
    PUB_SUB.subscribe(TOPICS.actions.remove.reactNative, reactNative.remove.handleReact)
    PUB_SUB.subscribe(TOPICS.actions.remove.rnIos, reactNative.remove.handleIos)
    PUB_SUB.subscribe(TOPICS.actions.remove.rnAndroid, reactNative.remove.handleAndroid)
    PUB_SUB.subscribe(TOPICS.actions.ERROR, this.handleError)
  }

  handleProgram(program) {
    LOG.verbose = program.verbose;
    if (program.framework) {
      LOG.info(`Setting up New Relic for --framework:${program.framework} and --platform(s):${program.platforms}`)
      PUB_SUB.publish(program.framework.toLowerCase(), program)
    }
  }

  handleRemove(program) {
    LOG.verbose = program.verbose;
    if (program.framework) {
      LOG.info(`Removing New Relic from --framework:${program.framework} and --platform(s):${program.platforms}`);
      PUB_SUB.publish(`remove.${program.framework.toLowerCase()}`, program)
    }
  }

  handleError(msg, args = {}) {
    LOG.debug(`Error ${args.toString()}`);
    LOG.error(msg)
  }

  handleTmpClean(program) {
    LOG.verbose = program.verbose
    LOG.info('Cleaning tmp folder')
    FILE_HELPER.removeFile(path.join(process.cwd(), PATHS.sourceMapTmpJs))
    .then(() => {
      LOG.debug('Removed sourcemap-tmp.js')
    })
    .catch((e) => {
      console.log(e)
    })

    FILE_HELPER.removeFile(path.join(process.cwd(), FILE_HELPER.prependCwd(PATHS.tmpJs)))
    .then(() => {
      LOG.debug('tmp.js')
    })
    .catch((e) => {
      console.log(e)
    })
  }
}