const LOG = require('../utils/logger')
const SERVICE_HELPER = require('./service-helpers')
const sourcemapUploader = module.exports;
const fs = require('fs')
const request = require('request')
const archiver = require('archiver')

/**
 * Uploads a source map file to New Relic for symbolication.
 * @param file: String. The source map file name
 * @param staging: Boolean. If uploading to New Relic's staging environment
 * @param token: String. App's App License Key
 * @param jsAppVersion: String. App's current version.
 * @param platform: String. iOS/Android
 */
sourcemapUploader.uploadMapFile = ({file, staging, token, jsAppVersion, platform}) => {
  const url = `${SERVICE_HELPER.getEnvironmentsUrl(token, staging)}/sourcemap`
  const zipPath = `${__dirname}/../tmp/map_${token}.zip`
  const output = fs.createWriteStream(zipPath)
  const archive = archiver('zip')

  archive.on('error', function(error) {
    throw error
  })

  output.on('error',function(error) {
    throw error
  })

  output.on('close', function() {
    LOG.debug('Archive closed.')
    const formData = {
      upload: fs.createReadStream(zipPath)
    }
    const headers = {
      'X-APP-LICENSE-KEY': token,
      'X-APP-OS-NAME': platform,
      'X-APP-JS-VERSION': jsAppVersion,
    }

    LOG.info('Preparing to upload js mapping file')
    LOG.debug(`Loading file ${file}`)
    LOG.debug(`Uploading to: ${url}`)

    request.post({url, formData, headers}, (error, response) => {

      fs.unlink(zipPath, function(){
        LOG.info(`removed ${zipPath}`)
      })

      if (error) {
        LOG.error(`Failed to upload: ${error}`)
        return error
      }

      if (response.statusCode === 201) {
        LOG.info(`Source map uploaded and created.`)
      }

      if (response.statusCode === 200) {
        LOG.info(`Successfully uploaded sourcemap.`)
      }

      if (response.statusCode > 201) {
        LOG.error(`response: ${response.statusCode} ${response.statusMessage}`)
      }

      return response
    })
  })

  output.on('open', function() {
    archive.pipe(output)
    archive.file(file, {name: file})
    archive.finalize()
  })
}
