const glob = require("glob");
const fs = require('fs');

const ERRORS = {
  NO_FILE_FOUND: 'Error: No File Found'
}

const IGNORE_FILES = ['node_modules/**', 'ios/Pods/**', '**/Pods/**', '**/newrelic-agent/**']

class FileHelper {
  constructor() {
  }

  checkForFile(pattern) {
    return new Promise(function (resolve, reject) {
      glob(pattern, {
        ignore: IGNORE_FILES,
      }, (er, matches) => {
        if (matches && matches.length) {
          return resolve(matches)
        }
        return reject(`${ERRORS.NO_FILE_FOUND} (${pattern})`)
      })
    })
  }

  readFileSync(filepath) {
    return new Promise(function (resolve, reject) {
      const fileBlob = fs.readFileSync(filepath, 'utf8');

      if (fileBlob) {
        return resolve(fileBlob)
      }
      return reject(`${ERRORS.NO_FILE_FOUND} (${filepath})`)
    })
  }

  writeFile(filepath, newFile) {
    return new Promise(function (resolve, reject) {
      fs.writeFile(filepath, newFile, 'utf8', (err) => {
        if (err) {
          return reject(err)
        }
        resolve(false)
      })
    })
  }

  removeFile(filepath) {
    return new Promise(function (resolve, reject) {
      fs.unlink(filepath, (err) => {
        if (err) {
          return reject(err)
        }
        resolve(false)
      })
    })
  }
}

const FILE_HELPER = new FileHelper()

module.exports = FILE_HELPER
