#!/usr/bin/env node
const package = require('./package')
const program = require('commander');
const setupCommands = require('./app/commands/setup');
const rnUploadCommand = require('./app/commands/rn-upload');
const rnUpload = require('./app/frameworks/react-native/rn-upload')
const App = require('./app');
const app = new App();

app.setup();

const {frameworks, platforms, deleteCmd, verbose} = setupCommands.options

program
  .version(package.version);

program
  .command(setupCommands.name)
  .option(frameworks.flags, frameworks.description)
  .option(platforms.flags, platforms.description, platforms.parser)
  .option(deleteCmd.flags, deleteCmd.description)
  .option(verbose.flags, verbose.description)
  .action(function (cmd) {
    app.handleProgram(cmd)
  });

program
  .command('remove')
  .option(frameworks.flags, frameworks.description)
  .option(platforms.flags, platforms.description, platforms.parser)
  .option(deleteCmd.flags, deleteCmd.description)
  .option(verbose.flags, verbose.description)
  .action(function (cmd) {
    app.handleRemove(cmd)
  });

program
  .command(rnUploadCommand.name)
  .option(rnUploadCommand.options.filePath.flags, rnUploadCommand.options.filePath.description)
  .option(rnUploadCommand.options.token.flags, rnUploadCommand.options.token.description)
  .option(rnUploadCommand.options.platform.flags, rnUploadCommand.options.platform.description)
  .option(rnUploadCommand.options.appVersion.flags, rnUploadCommand.options.appVersion.description)
  .option(rnUploadCommand.options.staging.flags, rnUploadCommand.options.staging.description)
  .option(verbose.flags, verbose.description)
  .option(rnUploadCommand.options.buildType.flags, rnUploadCommand.options.buildType.description)
  .action(function (cmd) {
    rnUpload.upload(cmd)
  });

program
  .command('clean-tmp')
  .option(verbose.flags, verbose.description)
  .action(function (cmd) {
    app.handleTmpClean(cmd)
  });

program.parse(process.argv);
